﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using DA = HeuristicLab.Services.Access.DataAccess;
using DT = HeuristicLab.Services.Access.DataTransfer;

namespace HeuristicLab.Services.Access.Tests {
  [TestClass]
  public class UnitTest {

    [TestMethod]
    public void ClearDB() {
      using (DA.ClientManagementDataContext context = new DA.ClientManagementDataContext()) {
        context.ExecuteCommand("DELETE FROM dbo.ResourceResourceGroup");
        context.ExecuteCommand("DELETE FROM dbo.Resource");
        context.ExecuteCommand("DELETE FROM dbo.ClientConfiguration");
        context.ExecuteCommand("DELETE FROM dbo.ClientError");
        context.ExecuteCommand("DELETE FROM dbo.ClientLog");
        context.ExecuteCommand("DELETE FROM dbo.ClientType");
        context.ExecuteCommand("DELETE FROM dbo.Country");
        context.ExecuteCommand("DELETE FROM dbo.OperatingSystem");
        context.ExecuteCommand("DELETE FROM dbo.ResourcePlugin");
        context.ExecuteCommand("DELETE FROM dbo.Plugin");
        context.ExecuteCommand("DELETE FROM dbo.UserGroupUserGroup");
        context.ExecuteCommand("DELETE FROM dbo.UserGroup");
      }
    }

    [TestMethod]
    public void AddClientTest() {
      ClearDB();
      AccessService service = new AccessService();
      DT.ClientConfiguration config = new DT.ClientConfiguration() { Description = "fatConfig", Hash = "xyz" };
      DT.Country country = new DT.Country() { Name = "Austria" };
      DT.ClientType clientType = new DT.ClientType() { Name = "Client" };
      DT.OperatingSystem os = new DT.OperatingSystem() { Name = "Windows 7" };

      DT.Client client = new DT.Client() {
        ClientConfiguration = config,
        ClientType = clientType,
        Country = country,
        Description = "testClient",
        HeuristicLabVersion = "3.3.6",
        MemorySize = 512,
        NumberOfCores = 4,
        Name = "testClient",
        OperatingSystem = os,
        ProcessorType = "Intel i7",
        Timestamp = DateTime.Now
      };

      Guid id = service.AddClient(client);
      Assert.IsTrue(service.ClientExists(id));
    }
  }
}
